@@ -5,6 +5,8 @@ from nonebot.typing import T_State
 from nonebot.adapters.onebot.v11 import Bot, MessageSegment, MessageEvent, GroupMessageEvent
 from nonebot import on_command
 import nonebot
+from nonebot import require
+from nonebot_plugin_apscheduler import scheduler
 from pathlib import Path
 from collections import Counter
 import json
@@ -12,8 +14,14 @@ import asyncio
 import os
 from .config import Config
 
+# 启动定时器
+
+
+require("nonebot_plugin_apscheduler")
 
 # 配置地址--------------------------------------------------------------------------------
+
+
 global_config = nonebot.get_driver().config
 pvz_config = Config.parse_obj(global_config.dict())
 pvz_basic_path = pvz_config.pvz_basic_path / \
@@ -22,7 +30,7 @@ pvz_basic_path = pvz_config.pvz_basic_path / \
 bag_path = pvz_basic_path / "user_data" / "bag.txt"
 lawn_path = pvz_basic_path / "user_data" / "lawn.txt"
 
-FONT_PATH = pvz_basic_path / "方正少儿GBK简体.ttf"
+FONT_PATH = pvz_basic_path / "font" / "msyh.ttf"
 
 PVZ_IMAGE_PATH = pvz_basic_path / 'images' / 'pvz' / 'base'
 PVZ_OUTPUT_PATH = pvz_basic_path / 'images' / 'pvz' / 'output'
@@ -31,6 +39,7 @@ PVZ_ORI_PATH = pvz_basic_path / 'images' / 'pvz' / 'ori'
 STATE_OK = True
 STATE_ERROR = False
 
+
 # 信息操作----------------------------------------------------------
 
 
@@ -61,11 +70,12 @@ def get_message_text(data: str) -> List[str]:
         for msg in data["message"]:
             if msg["type"] == "text":
                 text += msg["data"]["text"].strip() + " "
-        text = text.strip().split()
+        text = (text.strip().split())[1:]
         return text
     except KeyError:
         return []
 
+
 # 定义类------------------------------------------------------------------------------
 
 
@@ -650,16 +660,22 @@ def get_hp_down(
 
 # 绘制图片---------------------------------------------------------------------------
 
+
 def lawn_pic(plantname: List[str], cnt: int = 0):
     if not os.path.exists(PVZ_OUTPUT_PATH):
         os.makedirs(PVZ_OUTPUT_PATH)
+    if not os.path.exists(PVZ_IMAGE_PATH):
+        os.makedirs(PVZ_IMAGE_PATH)
     base_img = Image.open(Path(PVZ_IMAGE_PATH, "lawn.png")).convert("RGBA")
     for i in range(len(plantname)):
         if plantname[i] == "0":
             continue
         box = (0 + 250 * i, 0, 250 + 250 * i, 500)
 
-        tmp_img = Image.open(Path(PVZ_IMAGE_PATH, f"{plantname[i]}.png"))
+        tmp_img = Image.open(
+            Path(
+                PVZ_IMAGE_PATH,
+                f"{plantname[i]}.png"))
         region = tmp_img.crop((835, 290, 1085, 790))
         base_img.paste(region, box, region)
     base_img.save(Path(PVZ_OUTPUT_PATH, f"output{cnt}.png"))
@@ -668,6 +684,7 @@ def lawn_pic(plantname: List[str], cnt: int = 0):
 def zombie_pic(zombiename: str, dist: float, cnt: int = 0):
     if not os.path.exists(PVZ_OUTPUT_PATH):
         os.makedirs(PVZ_OUTPUT_PATH)
+
     base_img = Image.open(
         Path(
             PVZ_OUTPUT_PATH,
@@ -680,6 +697,8 @@ def zombie_pic(zombiename: str, dist: float, cnt: int = 0):
 
 
 def draw_test(text: str, color: Tuple, save_path: Path, fontpath: Path):
+    if not os.path.exists(PVZ_OUTPUT_PATH):
+        os.makedirs(PVZ_OUTPUT_PATH)
     img = Image.new("RGBA", (1080, 2400), color)
     draw = ImageDraw.Draw(img)
 
@@ -689,20 +708,22 @@ def draw_test(text: str, color: Tuple, save_path: Path, fontpath: Path):
     draw.text(xy=(100, 150), text=text, fill=(0, 0, 0), font=font)
     img.save(save_path)
 
-# 入侵流程
+
+# 入侵流程-----------------------------------------------------------------
 
 
 def one_by_one(team: List[str], plants: List[str]) -> (List, int):
     if not os.path.exists(PVZ_OUTPUT_PATH):
         os.makedirs(PVZ_OUTPUT_PATH)
     # 或去当前全部植物的对象
-    lawn_plants = [Plants(plant) for plant in plants]
-    # 全局时间
-    time = 0
+    lawn_plants = [Plants(all_plants[plant])
+                   for plant in plants if plant != "0"]
     # 判断是否胜利
     iswin = 0
     # 生成图片计数
     cnt = 0
+    # 僵尸序号
+    zcnt = 0
     # 入侵日志
     log = [
         {
@@ -715,6 +736,10 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
         }
     ]
     for zombie in team:
+        # 全局时间
+        time = 0
+        # 僵尸序号+1
+        zcnt += 1
         # 初始生成位置不变
         dist = 8
         # 获取现有每个植物的位置
@@ -723,7 +748,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
             i for i in range(
                 len(lawn_plants)) if lawn_plants[i].hp > 0]
         # 获取僵尸对象
-        zb = Zombie(zombie)
+        zb = Zombie(all_zombie[zombie])
         # 战斗是否开始，即僵尸是否会攻击植物
         fight_cond = 0
         # 每次开始到当前的战斗时间
@@ -731,7 +756,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
         # 在僵尸的两次攻击间隔内，植物造成的伤害
         all_damage = 0
         # 生成图片，写入日志
-        lawn_pic([all_plants[x] for x in plants], cnt)
+        lawn_pic([all_plants[x] for x in plants if x != "0"], cnt)
         zombie_pic(all_zombie[zombie], dist, cnt)
         log.append(
             {
@@ -749,7 +774,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                         {
                             "type": "image",
                             "data": {
-                                "file": "file:///" / PVZ_OUTPUT_PATH / f"output_new{cnt}.png"
+                                "file": f"file:///{PVZ_OUTPUT_PATH}/output_new{cnt}.png"
                             }
                         }
                     ]
@@ -759,7 +784,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
         # 图片计数序号递增
         cnt += 1
         # 当前僵尸循环，当僵尸死亡后退出，每次循环经过0.5秒
-        while zb.hp > 0:
+        while zb.hp > all_damage:
             # 计算当前僵尸距每个植物的距离
             distance = [dist - pos for pos in plant_pos if pos < dist]
             # 以0.5为僵尸的攻击距离
@@ -770,9 +795,10 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                 # 计算植物伤害
                 damage = get_hp_down(
                     zb, lawn_plants, time, dist, plant_pos)
-                # 扣除僵尸血量
-                zb.hp -= damage
 
+                # 不扣除僵尸血量，转而比较僵尸的血量与总伤害
+                # # 扣除僵尸血量
+                # zb.hp -= damage
                 # 设置战斗状态
                 fight_cond = 0
                 # 记录总伤害，便于打印日志
@@ -785,7 +811,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                     fight_time = 0
                     fight_cond = 1
                     # 生成图片，打印日志
-                    lawn_pic([all_plants[x] for x in plants], cnt)
+                    lawn_pic([all_plants[x] for x in plants if x != "0"], cnt)
                     zombie_pic(all_zombie[zombie], dist, cnt)
                     log.append(
                         {
@@ -797,7 +823,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                                     {
                                         "type": "image",
                                         "data": {
-                                            "file": "file:///" / PVZ_OUTPUT_PATH / f"output_new{cnt}.png"
+                                            "file": f"file:///{PVZ_OUTPUT_PATH}/output_new{cnt}.png"
                                         }
                                     }
                                 ]
@@ -812,7 +838,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                     # 距离递减
                     dist -= 1
                     # 生成图片
-                    lawn_pic([all_plants[x] for x in plants], cnt)
+                    lawn_pic([all_plants[x] for x in plants if x != "0"], cnt)
                     zombie_pic(all_zombie[zombie], dist, cnt)
                     # 如果是跳跳僵尸则不会失去下一次跳跃的功能
                     if zb.v == 0.4:
@@ -833,7 +859,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                                     {
                                         "type": "image",
                                         "data": {
-                                            "file": "file:///" / PVZ_OUTPUT_PATH / f"output_new{cnt}.png"
+                                            "file": f"file:///{PVZ_OUTPUT_PATH}/output_new{cnt}.png"
                                         }
                                     }
                                 ]
@@ -857,7 +883,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                                     {
                                         "type": "image",
                                         "data": {
-                                            "file": "file:///" / PVZ_OUTPUT_PATH / f"output_new{cnt}.png"
+                                            "file": f"file:///{PVZ_OUTPUT_PATH}/output_new{cnt}.png"
                                         }
                                     }
                                 ]
@@ -897,7 +923,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                 # 判断伤害
                 damage = get_hp_down(
                     zb, lawn_plants, time, dist, plant_pos)
-                zb.hp -= damage
+                # zb.hp -= damage
                 all_damage += damage
                 # 判断当前时间节点僵尸会不会进行攻击
                 if fight_time / \
@@ -911,7 +937,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                             "data": {
                                 "name": "疯狂戴夫",
                                 "uin": "1298919732",
-                                "content": f"时间{time},{zombie}对{plants[tar]}造成{zb.damage}点伤害。两次攻击间植物合计对{zombie}造成{all_damage}点伤害,{zombie}剩余血量为{zb.hp}"
+                                "content": f"时间{time},{zombie}对{plants[tar]}造成{zb.damage}点伤害。两次攻击间植物合计对{zombie}造成{all_damage}点伤害,{zombie}剩余血量为{zb.hp - all_damage}"
                             }
                         }
                         )
@@ -934,11 +960,11 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                             if tar == 0:
                                 iswin = 1
                                 break
-                        all_damage = 0
+                        # all_damage = 0
             # 总体时间递增
             time += 0.5
         # 判断游戏是否结束
-        if team.index(zombie) == len(team) - 1:
+        if iswin != 1 and zcnt == len(team):
             iswin = 2
         if iswin == 1:
             log.append({"type": "node",
@@ -947,7 +973,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                                  "content": [{"type": "text",
                                               "data": {"text": f"入侵成功！成功吃掉对方脑子！"}},
                                              {"type": "image",
-                                              "data": {"file": "file:///" / PVZ_ORI_PATH / "end.jpg"}}]}})
+                                              "data": {"file": f"file:///{PVZ_ORI_PATH}/end.jpg"}}]}})
             break
         elif iswin == 2:
             log.append({
@@ -958,7 +984,7 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                     "content": f"僵尸{zombie}被击败，所有僵尸均死去,入侵结束"
                 }
             })
-        else:
+        elif iswin == 0:
             log.append({
                 "type": "node",
                 "data": {
@@ -968,10 +994,13 @@ def one_by_one(team: List[str], plants: List[str]) -> (List, int):
                 }
             }
             )
+
     return log, iswin
 
 
 # 初始化全局变量-------------------------------------------------------------------------
+
+
 now_env = "白天"
 
 all_plants = {
@@ -1041,6 +1070,7 @@ play_with_computer_plant = on_command(
 _help = on_command("植物大战僵尸帮助", aliases={"pvz帮助"}, priority=5, block=True)
 fight = on_command("入侵", priority=5, block=True)
 
+
 # pvz签到-----------------------------------------------------------------------------
 
 
@@ -1050,10 +1080,15 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
     users_id = [x[0] for x in users]
     user_id = str(event.user_id)
     if user_id in users_id:
-        users[users_id.index(user_id)][3] = str(
-            int(users[users_id.index(user_id)][3]) + 100)
-        flag = write_data(Path(bag_path), users)
-        msg = "今天获得了50阳光，已经放入您的背包"
+        if users[users_id.index(user_id)][4] == "0":
+            users[users_id.index(user_id)][3] = str(
+                int(users[users_id.index(user_id)][3]) + 100)
+            users[users_id.index(user_id)][4] = "1"
+            flag = write_data(Path(bag_path), users)
+            msg = "今天获得了50阳光，已经放入您的背包"
+        else:
+            msg = "贪心的人是不会有好远的哦...您今天已经签到过啦！"
+
     else:
         msg = "您暂未注册植物大战僵尸功能，可以通过“查看背包”或“我的背包”来进行注册"
     await pvz_signin.finish(msg, at_sender=True)
@@ -1070,7 +1105,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
     user_id = str(event.user_id)
     # 判断用户
     if user_id in users_id:
-        _, plants, zombies, sunshine = users[users_id.index(user_id)]
+        _, plants, zombies, sunshine, _ = users[users_id.index(user_id)]
         res = ""
         if plants == "0":
             res += "您暂未有任何植物储存，可以去查看商店购买"
@@ -1097,7 +1132,8 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         await asyncio.sleep(1)
         await look_bag.finish(res, at_sender=True)
     else:
-        users.append([user_id, "豌豆射手", "普通僵尸", "0"])
+        # 储存格式为 user_id 拥有植物 拥有僵尸 拥有阳光 是否签到
+        users.append([user_id, "豌豆射手", "普通僵尸", "100", "1"])
         flag = write_data(Path(bag_path), users)
         await asyncio.sleep(1)
         if flag:
@@ -1105,6 +1141,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         else:
             await look_bag.finish("写入文件出错，请联系管理员")
 
+
 # 查看草坪-----------------------------------------------------------------------------
 
 
@@ -1130,7 +1167,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
                     res += f"位置{i + 1}:{lawn_plants[i]}\n"
             res += "**********\n实际的布置位置的序号从左到右为1,2,3,4,5,6,即僵尸会有限攻击6号位植物"
             # 生成草坪图片
-            lawn_pic([all_plants[x] for x in lawn_plants])
+            lawn_pic([all_plants[x] for x in lawn_plants if x != "0"])
             img = MessageSegment.image(
                 "file:///" / PVZ_OUTPUT_PATH / "output0.png")
             res = MessageSegment.text(res) + img
@@ -1147,12 +1184,12 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
             res = "当前您的草坪布置:\n"
             for i in range(len(lawn_plants)):
                 if lawn_plants[i] == "0":
-                    res += f"位置{i+1}:空\n"
+                    res += f"位置{i + 1}:空\n"
                 else:
-                    res += f"位置{i+1}:{lawn_plants[i]}\n"
+                    res += f"位置{i + 1}:{lawn_plants[i]}\n"
             res += "**********\n实际的布置位置的序号从左到右为1,2,3,4,5,6,即僵尸会有限攻击6号位植物"
             # 生成草坪图片
-            lawn_pic([all_plants[x] for x in lawn_plants])
+            lawn_pic([all_plants[x] for x in lawn_plants if x != "0"])
             img = MessageSegment.image(
                 "file:///" / PVZ_OUTPUT_PATH / "output0.png")
             res = MessageSegment.text(res) + img
@@ -1168,6 +1205,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
                 await asyncio.sleep(1)
                 await look_lawn.finish("写入文件出错，请联系管理员")
 
+
 # 查看商店-----------------------------------------------------------------------------
 
 
@@ -1181,11 +1219,12 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 @look_shop.got("type", prompt="您想要查看植物还是僵尸?")
 async def _(bot: Bot, event: MessageEvent, state: T_State):
     res = ""
-    print(state["type"])
+    if not isinstance(state["type"], str):
+        state["type"] = str(state["type"])
     if state["type"] == "植物":
         res += "当前在售的植物有：\n"
         for i in range(len(all_plants.items())):
-            res += f"{i+1}.{list(all_plants.items())[i][0]}的售价为{plants_price[i]};\n"
+            res += f"{i + 1}.{list(all_plants.keys())[i]}的售价为{plants_price[i]};\n"
         res += "可以通过关键字'购买'+名称来购买植物"
         draw_test(
             res, (255, 255, 153), Path(
@@ -1195,7 +1234,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
     elif state["type"] == "僵尸":
         res += "当前在售的僵尸为：\n"
         for i in range(len(all_zombie.items())):
-            res += f"{i+1}.{list(all_zombie.keys())[i]}的售价为{zombie_price[i]};\n"
+            res += f"{i + 1}.{list(all_zombie.keys())[i]}的售价为{zombie_price[i]};\n"
         res += "可以通过关键字'购买'+名称来购买僵尸"
         draw_test(
             res, (255, 255, 153), Path(
@@ -1208,14 +1247,16 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 
 
 # 查看图鉴-----------------------------------------------------------------------------
+
+
 @look_pvz.handle()
 async def _(bot: Bot, event: MessageEvent, state: T_State):
     args = get_message_text(event.json())
     if args and (
-        (args[0] in list(
-            all_plants.keys())) or (
-            args[0] in list(
-                all_zombie.keys()))):
+            (args[0] in list(
+                all_plants.keys())) or (
+                    args[0] in list(
+                        all_zombie.keys()))):
         # 如果附加了所要查看的图鉴则不需要询问
         state["cate"] = args[0]
 
@@ -1223,12 +1264,14 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 @look_pvz.got("cate", prompt="您想要查看哪种植物或者僵尸?如果不知道都有那些名字可以通过'查看商店'来查看")
 async def _(bot: Bot, event: MessageEvent, state: T_State):
     res = ""
+    if not isinstance(state["cate"], str):
+        state["cate"] = str(state["cate"])
     if state["cate"] in list(all_plants.keys()):
         res += f"{state['cate']}的属性如下:\n"
         plt = Plants(all_plants[state["cate"]])
         res += f"生命值为{plt.hp}\n"
         res += f"伤害为{plt.damage}/{plt.damage_interval}s\n"
-        res += f"攻击距离为({plt.damage_distance[0]}, {12 if plt.damage_distance[1]==np.inf else plt.damage_distance[1]})\n"
+        res += f"攻击距离为({plt.damage_distance[0]}, {12 if plt.damage_distance[1] == np.inf else plt.damage_distance[1]})\n"
         res += f"攻击使僵尸的属性为先前的{plt.effect}\n"
         if plt.penetrable:
             res += f"此植物的攻击有穿透效果\n"
@@ -1240,7 +1283,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
             res += f"此植物仅被伽刚特尔伤害\n"
         res += f"购买需要阳光{plt.price}"
         img = MessageSegment.image(
-            "file:///" / PVZ_ORI_PATH / f"{state['cate']}.jpg")
+            "file:///" / PVZ_ORI_PATH / f"{all_plants[state['cate']]}.jpg")
         res = MessageSegment.text(res) + img
     elif state["cate"] in list(all_zombie.keys()):
         res += f"{state['cate']}的属性如下:\n"
@@ -1256,13 +1299,14 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
             res += "该僵尸可以忽视植物攻击带来的效果削弱\n"
         res += f"购买需要阳光{zomb.price}"
         img = MessageSegment.image(
-            "file:///" / PVZ_ORI_PATH / f"{state['cate']}.jpg")
+            "file:///" / PVZ_ORI_PATH / f"{all_zombie[state['cate']]}.jpg")
         res = MessageSegment.text(res) + img
     else:
         res += "不合法输入，可以通过'查看商店'来查询支持的植物或僵尸"
     await asyncio.sleep(1)
     await look_pvz.finish(res, at_sender=True)
 
+
 # 购买--------------------------------------------------------------------------------
 
 
@@ -1273,16 +1317,16 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
     users_id = [x[0] for x in users]
     user_id = str(event.user_id)
     if user_id in users_id:
-        _, state["plants"], state["zombies"], state["sunshine"] = users[users_id.index(
+        _, state["plants"], state["zombies"], state["sunshine"], _ = users[users_id.index(
             user_id)]
         state["users"] = users
         state["index"] = users_id.index(user_id)
         args = get_message_text(event.json())
         if args and (
-            (args[0] in list(
-                all_plants.keys())) or (
-                args[0] in list(
-                all_zombie.keys()))):
+                (args[0] in list(
+                    all_plants.keys())) or (
+                        args[0] in list(
+                            all_zombie.keys()))):
             # 如果附加了所要购买的植物或者僵尸则不需要询问
             state["cate"] = args[0]
     else:
@@ -1292,6 +1336,8 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 
 @buy.got("cate", prompt="您想要购买哪种植物或者僵尸?如果不知道都有那些名字可以通过'查看商店'来查看")
 async def _(bot: Bot, event: MessageEvent, state: T_State):
+    if not isinstance(state["cate"], str):
+        state["cate"] = str(state["cate"])
     if state["cate"] in list(all_plants.keys()):
         price = plants_price[list(all_plants.keys()).index(state["cate"])]
         if price > int(state["sunshine"]):
@@ -1326,6 +1372,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         await asyncio.sleep(1)
         await buy.finish("您输入的名称有误，购买失败", at_sender=True)
 
+
 # 放置--------------------------------------------------------------------------------
 
 
@@ -1341,14 +1388,14 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         state["index"] = users_id.index(user_id)
         # 读取背包数据，用于后续判断
         flag, users = read_data(Path(bag_path))
-        _, state["plants"], _, _ = users[users_id.index(user_id)]
+        _, state["plants"], _, _, _ = users[users_id.index(user_id)]
         args = get_message_text(event.json())
         if args and (
-            (args[0] in list(
-                all_plants.keys())) or (
-                args[0] in list(
-                all_zombie.keys()))):
-            state["cate"] = args[0]
+                (args[0] in list(
+                    all_plants.keys())) or (
+                        args[0] in list(
+                            all_zombie.keys()))):
+            state["cate"] = " ".join(args)
     else:
         await asyncio.sleep(1)
         await buy.finish("您暂未开启草坪，请通过'查看草坪'开启", at_sender=True)
@@ -1358,6 +1405,8 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
 async def _(bot: Bot, event: MessageEvent, state: T_State):
     if not os.path.exists(PVZ_OUTPUT_PATH):
         os.makedirs(PVZ_OUTPUT_PATH)
+    if not isinstance(state["cate"], str):
+        state["cate"] = str(state["cate"])
     temp = state["cate"].split(" ")
     if len(temp) == 2 and 0 < int(temp[1]) <= 6:
         plant, pos = state["cate"].split(" ")
@@ -1373,7 +1422,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
                 if flag:
                     await asyncio.sleep(1)
                     # 获取图片
-                    lawn_pic([all_plants[x] for x in now_pos])
+                    lawn_pic([all_plants[x] for x in now_pos if x != "0"])
                     img = MessageSegment.image(
                         "file:///" / PVZ_OUTPUT_PATH / "output0.png")
                     res = MessageSegment.text(
@@ -1395,6 +1444,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         await asyncio.sleep(1)
         await put_on_lawn.finish("输入格式有误，输入样例:'豌豆射手 1'", at_sender=True)
 
+
 # 入侵--------------------------------------------------------------------------------
 
 
@@ -1424,8 +1474,10 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
         await fight.finish("请至少@一个开启草坪的人来进行入侵", at_sender=True)
 
 
-@fight.got("team", prompt="请尽快选择您要入侵的阵容，多个僵尸中间用空格分割(最多不超过三个)，默认方式为一个一个出场，。例如'普通僵尸 普通僵尸 撑杆僵尸'")
+@fight.got("team", prompt="请尽快选择您要入侵的阵容，多个僵尸中间用空格分割(最多不超过三个)，默认方式为一个一个出场。\n例如'普通僵尸 普通僵尸 撑杆僵尸'")
 async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+    if not isinstance(state["team"], str):
+        state["team"] = str(state["team"])
     # 获取入侵小队
     zombie_team = state["team"].split(" ")
     bag_zombie = state["bag_zombie"]
@@ -1460,6 +1512,7 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
             # 发送数据
             await bot.send_group_forward_msg(group_id=event.group_id, messages=log)
 
+
 # 植物人机训练--------------------------------------------------------------------------
 
 
@@ -1480,6 +1533,8 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
 
 @play_with_computer_zombie.got("mode", prompt="请选择难度模式，可选择易，中，难,地狱四种不同级别的难度")
 async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+    if not isinstance(state["mode"], str):
+        state["mode"] = str(state["mode"])
     mode = state["mode"].strip()
     if mode in ["易", "中", "难", "地狱"]:
         if mode == "易":
@@ -1495,7 +1550,8 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
         await bot.send_group_forward_msg(group_id=event.group_id, messages=log)
         await asyncio.sleep(0.5)
         if iswin == 1:
-            await play_with_computer_zombie.finish(f"很遗憾您没能通过难度为{mode}的植物人机训练，此次出场的僵尸阵容为{','.join(zombie_team)}", at_sender=True)
+            await play_with_computer_zombie.finish(f"很遗憾您没能通过难度为{mode}的植物人机训练，此次出场的僵尸阵容为{','.join(zombie_team)}",
+                                                   at_sender=True)
         else:
             await play_with_computer_zombie.finish(f"恭喜您成功通过难度为{mode}的植物人机训练，此次出场的僵尸阵容为{','.join(zombie_team)}",
                                                    at_sender=True)
@@ -1505,6 +1561,8 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
 
 
 # 僵尸人机训练----------------------------------------------------------------------------------------
+
+
 @play_with_computer_plant.handle()
 async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
     flag, users = read_data(Path(bag_path))
@@ -1524,6 +1582,8 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
 async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
     if not os.path.exists(PVZ_OUTPUT_PATH):
         os.makedirs(PVZ_OUTPUT_PATH)
+    if not isinstance(state["mode"], str):
+        state["mode"] = str(state["mode"])
     mode = state["mode"].strip()
     if mode in ["易", "中", "难", "地狱"]:
         if mode == "易":
@@ -1535,9 +1595,10 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
         else:
             plant_team = ["冰瓜", "玉米投手", "机枪射手", "火炬", "高坚果", "地刺王"]
         state["plants"] = plant_team
-        lawn_pic([all_plants[x] for x in plant_team])
+        lawn_pic([all_plants[x] for x in plant_team if x != "0"])
         await asyncio.sleep(0.5)
-        await play_with_computer_plant.send(MessageSegment.text("本次对抗的草坪阵容为") + MessageSegment.image("file:///" / PVZ_OUTPUT_PATH / "output0.png"))
+        await play_with_computer_plant.send(
+            MessageSegment.text("本次对抗的草坪阵容为") + MessageSegment.image("file:///" / PVZ_OUTPUT_PATH / "output0.png"))
     else:
         await asyncio.sleep(1)
         await play_with_computer_plant.finish("您选择的难度有误，小小垚看不懂，请重新选择", at_sender=True)
@@ -1546,6 +1607,10 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
 @play_with_computer_plant.got("team",
                               prompt="请选择您的僵尸入侵小队，僵尸之间用空格分割，最多选择三个僵尸，例如'普通僵尸 普通僵尸 普通僵尸'")
 async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+    if not isinstance(state["mode"], str):
+        state["mode"] = str(state["mode"])
+    if not isinstance(state["team"], str):
+        state["team"] = str(state["team"])
     mode = state["mode"].strip()
     zombie_team = state["team"].split(" ")
     bag_zombie = state["zombies"]
@@ -1582,6 +1647,7 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
             await play_with_computer_plant.finish(f"很遗憾您没能通过难度为{mode}的僵尸人机训练",
                                                   at_sender=True)
 
+
 # 帮助---------------------------------------------------------------------------------
 
 
@@ -1618,8 +1684,24 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
     await _help.finish(MessageSegment.image("file:///" / PVZ_OUTPUT_PATH / "help.png"), at_sender=True)
 
 
+# 定时操作，更改签到数据----------------------------------------------------------------
+
+
+@scheduler.scheduled_job("cron", day="*")
+async def run_every_day_to_reset_signin_data():
+    flag, users = read_data(Path(bag_path))
+    for i in range(len(users)):
+        users[i][4] = "0"
+    flag = write_data(Path(bag_path), users)
+    if flag:
+        print("********植物大战僵尸签到数据已重置*********")
+    else:
+        print("********植物大战僵尸签到数据重置失败*********")
+
+
 # 文档操作----------------------------------------------------------------------------
 
+
 def write_data(path: Path, data: list) -> bool:
     try:
         if data:
@@ -1650,4 +1732,4 @@ def read_data(path: Path) -> (bool, list):
         return STATE_OK, infos
     except BaseException as e:
         print(e)
-        return STATE_ERROR, []
+        return STATE_ERROR, []
\ No newline at end of file
